## [v0.2.0](https://github.com/Jelly-RDF/pyjelly/tree/v0.2.0) (2025-06-03)

### Added

- Added changelog ([#103](https://github.com/Jelly-RDF/pyjelly/issues/103))
- Stream types inference ([#120](https://github.com/Jelly-RDF/pyjelly/issues/120))

### Changed

- RDFLib exposed as an optional dependency installable with `pyjelly[rdflib]` ([#129](https://github.com/Jelly-RDF/pyjelly/issues/129))

### Fixed

- A bug where empty prefixes were not serialized ([#127](https://github.com/Jelly-RDF/pyjelly/issues/127))


# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/).<br/>
This project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->